@@ -15,13 +15,17 @@ import click
 
 from mojo.xmods.jsos import load_jsos_stream_from_file
 
+from mojo.xmods.xclick import NORMALIZED_STRING
+
 HELP_RESULTS = "A folder containing test results to publish"
 HELP_EXPIRY = "A number of days to persist the up uploaded results."
+HELP_ARCHIVE = "An optional 'archive' value to set in the build document."
 
 @click.command("create")
 @click.option("--results", required=True, type=click.Path(exists=True, file_okay=False), help=HELP_RESULTS)
+@click.option("--archive", required=False, type=NORMALIZED_STRING, default=None, help=HELP_ARCHIVE)
 @click.argument('filename', metavar='<testrun document>', type=click.Path(dir_okay=False))
-def command_pycis_document_testrun_create(results: str, filename: str):
+def command_pycis_document_testrun_create(results: str, archive: str, filename: str):
 
     # Make sure the summary document and the tests document exists
     summary_file = os.path.join(results, "testrun_summary.json")
@@ -39,12 +43,12 @@ def command_pycis_document_testrun_create(results: str, filename: str):
     document = {
         "dversion": "1.0",
         "dtype": "testrun",
-        "resultitems": trstream
+        "resultitems": trstream,
+        "archive": archive
     }
 
     document.update(summary)
 
-
     with open(filename, 'w') as of:
         json.dump(document, of, indent=4)
 
